pub struct QueryScalar { /* private fields */ }Expand description
Execute a SELECT query and return a single scalar value.
The query must return exactly one row with one column.
Examples
use ironflow_ops_postgres::query::QueryScalar;
use ironflow_core::operation::Operation;
let op = QueryScalar::new(pool, "SELECT count(*) FROM users", vec![]);
assert_eq!(op.kind(), "postgres");Implementations
Sourceimpl QueryScalar
impl QueryScalar
Sourcepub fn new(pool: PgPool, sql: impl Into<String>, params: Vec<Value>) -> Self
pub fn new(pool: PgPool, sql: impl Into<String>, params: Vec<Value>) -> Self
Create a new query-scalar operation.
Sourcepub async fn run(
&self,
_ctx: &OperationContext,
) -> Result<QueryScalarOutput, OperationError>
pub async fn run( &self, _ctx: &OperationContext, ) -> Result<QueryScalarOutput, OperationError>
Execute and return a typed result.
Errors
Returns OperationError::External on SQL/connection errors or if the
query does not return exactly one row with one column.